"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const webpack_merge_1 = require("webpack-merge");
const getOutput_1 = __importDefault(require("./getOutput"));
const getLoaders_1 = __importDefault(require("./getLoaders"));
const getPlugins_1 = __importDefault(require("./getPlugins"));
const getOptimization_1 = __importDefault(require("./getOptimization"));
const mock_1 = __importDefault(require("./middleware/mock"));
const logger_1 = __importDefault(require("./middleware/logger"));
const utils_1 = __importDefault(require("./utils"));
const paths_1 = __importDefault(require("./paths"));
const entry = ['./src/index'];
function getExtraWebpackConfig(webpackConfig) {
    let path = '';
    if (utils_1.default.isDev()) {
        path = paths_1.default.getResolvePath('webpack.config.dev.js');
    }
    if (utils_1.default.isProduction()) {
        path = paths_1.default.getResolvePath('webpack.config.prod.js');
    }
    if (!(path && fs_1.default.existsSync(path))) {
        const webpackConfig = paths_1.default.getResolvePath('webpack.config.js');
        if (webpackConfig && fs_1.default.existsSync(webpackConfig)) {
            path = webpackConfig;
        }
    }
    if (!path) {
        return {};
    }
    try {
        const config = utils_1.default.requireModule(path);
        if (typeof config === 'function') {
            return config(webpackConfig);
        }
        return config;
    }
    catch (e) {
        return {};
    }
}
const HOST = '0.0.0.0';
const PORT = 3000;
exports.default = (rcb, options) => {
    const devServerConfig = {
        host: rcb.host || HOST,
        port: rcb.port || PORT,
        proxy: rcb.proxy,
        historyApiFallback: {
            htmlAcceptHeaders: ['text/html', 'application/xhtml+xml', 'application/xml']
        },
        compress: true,
        client: {
            logging: "error",
            overlay: false
        },
        allowedHosts: 'all',
        open: false,
        devMiddleware: {
            stats: false
        },
        setupMiddlewares(middlewares, devServer) {
            const mockConfig = rcb.mock;
            if ((options === null || options === void 0 ? void 0 : options.mock) && mockConfig) {
                // mock代理的url不会在node中log出来，只有proxy代理的url才会log方便查看是哪里出了问题
                devServer.app.use(mockConfig.api, mock_1.default.middleware(rcb.mock));
            }
            middlewares.push(logger_1.default());
            return middlewares;
        }
    };
    const defaultWebpackConfig = {
        mode: utils_1.default.getEnv(),
        performance: {
            hints: false
        },
        stats: false,
        devServer: utils_1.default.isDev() ? Object.assign(devServerConfig, rcb.devServer) : undefined,
        devtool: utils_1.default.isDev() && rcb.devtool ? rcb.devtool : false,
        entry: rcb.entry || entry,
        infrastructureLogging: {
            level: 'error'
        },
        output: getOutput_1.default(rcb.output),
        module: {
            rules: getLoaders_1.default(rcb)
        },
        optimization: getOptimization_1.default(rcb),
        plugins: getPlugins_1.default(rcb),
        resolve: {
            modules: ['node_modules', paths_1.default.appNodeModules].concat(rcb.additionalModulePaths || []),
            alias: rcb.alias,
            extensions: ['.js', '.jsx', '.es6', '.json', '.ts', '.tsx', '.mjs'],
            fallback: {
                "fs": false,
                "tls": false,
                "net": false,
                "path": false,
                "zlib": false,
                "http": false,
                "https": false,
                "stream": false,
                "crypto": false
            }
        },
        watchOptions: utils_1.default.isDev() ? {
            poll: 100,
            ignored: ["node_modules"]
        } : undefined
    };
    const config = webpack_merge_1.merge(defaultWebpackConfig, getExtraWebpackConfig(defaultWebpackConfig));
    return webpack_merge_1.merge(config, typeof rcb.webpack === 'function'
        ? rcb.webpack(config)
        : rcb.webpack || {});
};
