"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
require("./babelRegister");
const webpack_1 = __importDefault(require("webpack"));
const webpack_dev_server_1 = __importDefault(require("webpack-dev-server"));
const utils_1 = __importDefault(require("./utils"));
const clearConsole_1 = __importDefault(require("./clearConsole"));
const getConfig_1 = __importDefault(require("./getConfig"));
const compilerErrorHandle_1 = __importDefault(require("./compilerErrorHandle"));
const openBrower_1 = __importDefault(require("./openBrower"));
const webpackBar_1 = __importDefault(require("./common/webpackBar"));
// 将devserver初始化log信息清除
// @ts-ignore
class DevServer extends webpack_dev_server_1.default {
    constructor(...args) {
        // @ts-ignore
        super(...args);
    }
    // @override
    logStatus() {
        return null;
    }
}
function runServer(options) {
    const webpackConfig = getConfig_1.default(options).webpack;
    const devServerConfig = webpackConfig.devServer || {};
    const URL = `http://${devServerConfig.host}:${devServerConfig.port}`;
    const compiler = webpack_1.default(webpackConfig);
    const server = new DevServer(devServerConfig, compiler);
    let isFirstCompiler = true;
    compiler.hooks.beforeCompile.tap('beforeCompile', function () {
        if (isFirstCompiler) {
            webpackBar_1.default.update(0); // 优化：初始化时先展示0%时的webpack bar
            return;
        }
        clearConsole_1.default();
        utils_1.default.success(utils_1.default.chalk.green('Rebuild start...'));
    });
    compiler.hooks.afterDone.tap('dev server', function (stats) {
        if (isFirstCompiler) {
            const proxyPaths = utils_1.default.getWebpackProxyPath(webpackConfig);
            utils_1.default.success(utils_1.default.chalk.green('Compiled successfully!'));
            utils_1.default.success(`${utils_1.default.chalk.green('Local:')}  ${URL}`);
            if (proxyPaths.length > 0) {
                utils_1.default.success(`${utils_1.default.chalk.green('Proxy:')}  [${proxyPaths.join(', ')}]`);
            }
            isFirstCompiler = false;
            (devServerConfig === null || devServerConfig === void 0 ? void 0 : devServerConfig.open) && openBrower_1.default(URL);
        }
        else {
            utils_1.default.success(utils_1.default.chalk.green('Compiled successfully!'));
        }
        compilerErrorHandle_1.default(stats, null, isFirstCompiler);
    });
    if (!devServerConfig.port || !devServerConfig.host) {
        utils_1.default.error(`port: ${devServerConfig.port}, host: ${devServerConfig.host}`);
        process.exit(0);
    }
    server
        .start()
        .catch((e) => {
        console.log(e);
        if (e) {
            utils_1.default.error(e.message);
            process.exit(0);
        }
    });
}
exports.default = runServer;
