import TerserPlugin from 'terser-webpack-plugin';
import { RcbConfig } from './getConfig';

import utils from './utils';

export default function getOptimization(rcb: RcbConfig) {
    let baseOptim: any = {
        runtimeChunk: {
            name: (entrypoint: any) => `runtime-${entrypoint.name}`,
        }
    };

    if (utils.isProduction()) {
        baseOptim = Object.assign({}, baseOptim, {
            splitChunks: {
                chunks: 'all',
                name: false
            },
            minimize: true,
            minimizer: [new TerserPlugin({
                extractComments: false,
                terserOptions: {
                    parse: {
                        ecma: 5,
                    },
                    compress: {
                        ecma: 5,
                        comparisons: false,
                        inline: 2,
                    },
                    mangle: {
                        safari10: true,
                    },
                    output: {
                        ecma: 5,
                        comments: false,
                        ascii_only: true,
                    },
                }
            })]
        });
    }

    return baseOptim;
};
