import { Request, Response, NextFunction } from 'express';
import utils from '../utils';

export default function loggerMiddleware() {
    return function (req: Request, res: Response, next: NextFunction) {
        const url = req.url;
        if (
            /\.(css|css|js|png|jpg|svg|gif|html|text|doc|ico|hot-update.json|hot-update.js)$/.test(url)
            || url === '/'
        ) {
            return next();
        }
        const startDate = Date.now();
        next();

        const msg = `[${req.method}] ${url}  ${res.statusCode} ${Date.now() - startDate}ms`;
        if (res.statusCode >= 400) {
            utils.warning(msg);
        }
        else {
            utils.logger(msg);
        }
    };
};
